# pyFrame3DD Changelog

## 0.2.0 (July 8, 2014)

Garrett Barter <garrett.barter@nrel.gov>

- Updating to 2014 version of Frame3DD and improved installation robustness

## 0.1.0 (July 8, 2014)

Andrew Ning <andrew.ning@nrel.gov>

- initial relase
